@@ -1,6 +1,6 @@
 package Tapper::MCP::Scheduler::Job;
 our $AUTHORITY = 'cpan:TAPPER';
-$Tapper::MCP::Scheduler::Job::VERSION = '5.0.8';
+$Tapper::MCP::Scheduler::Job::VERSION = '5.0.9';
 use strict;
 use warnings;
 
@@ -52,6 +52,20 @@ has requested_hosts => (is => "ro",
                                 }
                                 return \@return_hosts;
                         });
+has requested_resources => (is => "ro",
+                            lazy => 1,
+                            default => sub {
+                                my ($self) = shift;
+                                my $resource_reqs = Tapper::Model::model('TestrunDB')->resultset('TestrunRequestedResource')->search(
+                                        {testrun_id => $self->testrun_id},{ prefetch => 'alternatives' });
+
+                                my @requested_resources;
+                                while (my $resource_req = $resource_reqs->next) {
+                                        push @requested_resources, $resource_req;
+                                }
+
+                                return \@requested_resources;
+                        });
 has queue         => (is => 'ro',
                       lazy => 1,
                       default => sub {
@@ -91,7 +105,6 @@ sub match_host {
 
 our @functions;
 BEGIN {
-        no if $] >= 5.017011, warnings => 'experimental::smartmatch';
         my $features = Tapper::Model::model->resultset('HostFeature')->search(
                                                                               {
                                                                               },
@@ -109,13 +122,13 @@ BEGIN {
 
                             if (\$given) {
                                     # available
-                                    return \$given ~~ \$_->{features}->{$entry};
+                                    return \$given eq \$_->{features}->{$entry};
                             } else {
                                     return \$_->{features}->{$entry} };
                     }";
                 eval $eval_string; ## no critic
         }
-        if ( not grep {$_ ~~ /hostname/} @functions ) {
+        if ( not grep {$_ =~ /hostname/} @functions ) {
                 eval '
                 sub hostname (;$) ## no critic (ProhibitSubroutinePrototypes)
                               {
@@ -123,7 +136,7 @@ BEGIN {
 
                                       if ($given) {
                                               # available
-                                              return $given ~~ $_->{features}->{hostname};
+                                              return $given eq $_->{features}->{hostname};
                                       } else {
                                               return $_->{features}->{hostname};
                                       }
@@ -164,8 +177,66 @@ sub match_feature {
         return;
 }
 
+# Tries to acquire resources for job
+# Returns 2 values
+# - If all requested resources are available
+# - Which resources were acquired (array ref) or undef if not possible
+sub claim_resources {
+        my ($self, $free_resources) = @_;
 
+        my %res_lookup;
+        $res_lookup{$_->id} = $_ foreach (@$free_resources);
 
+        my @acquire_resources;
+
+        # Transaction, rollback unless commit is called on this
+        my $guard = Tapper::Model->model('TestrunDB')->txn_scope_guard;
+
+        foreach my $res_request (@{$self->requested_resources})
+        {
+                my $best_alternative;
+                foreach my $res_alternative ($res_request->alternatives)
+                {
+                        if (my $resource = $res_lookup{$res_alternative->resource_id})
+                        {
+                                $best_alternative = $resource;
+                                last;
+                        }
+                }
+
+                return (0,undef) unless defined $best_alternative;
+
+                # Remove from lookup so it won't be chose twice.
+                delete $res_lookup{$best_alternative->id};
+
+                # Remember choice for frontends
+                $res_request->selected_resource($best_alternative);
+                $res_request->update;
+
+                # Mark as in use
+                $best_alternative->used_by_scheduling_id($self->{id});
+                $best_alternative->update;
+
+                push @acquire_resources, $best_alternative;
+        }
+
+        $guard->commit;
+
+        return (1, \@acquire_resources);
+}
+
+# Checks whether all testruns that our job depends on have finished.
+sub dependencies_finished {
+        my ($self) = @_;
+        my $unfinished_dependency = Tapper::Model::model('TestrunDB')->resultset('TestrunDependency')->search({
+                'depender_testrun_id' => $self->testrun_id,
+                'testrun_scheduling.status' => { '!=', 'finished' },
+        },{
+                'join' => { dependee => 'testrun_scheduling' },
+        })->first;
+
+        return !defined($unfinished_dependency);
+}
 
 # Checks a TestrunScheduling against a list of available hosts
 # returns the matching host
@@ -261,7 +332,7 @@ Tapper Team <tapper-ops@amazon.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2019 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2024 by Advanced Micro Devices, Inc.
 
 This is free software, licensed under:
 
