@@ -1,6 +1,6 @@
 package Tapper::MCP::Scheduler::Queue;
 our $AUTHORITY = 'cpan:TAPPER';
-$Tapper::MCP::Scheduler::Queue::VERSION = '5.0.8';
+$Tapper::MCP::Scheduler::Queue::VERSION = '5.0.9';
 use strict;
 use warnings;
 
@@ -81,7 +81,8 @@ sub jobs
 
 sub get_first_fitting
 {
-        my ($self, $free_hosts) = @_;
+        my ($self, $free_hosts, $available_resources) = @_;
+        $available_resources = [] unless defined $available_resources;
 
         my @forbidden_host_names;
         @forbidden_host_names = map {$_->name} @{$self->deniedhosts};
@@ -93,17 +94,27 @@ sub get_first_fitting
 
         foreach my $job (@{$self->testrunschedulings}) {
                 my $host = $job->fits($free_hosts);
-                if ($host) {
-                        my $db_job = model('TestrunDB')->resultset('TestrunScheduling')->find($job->{id});
-                        $db_job->host_id ($host->id);
+                next unless $host;
 
-                        if ($db_job->testrun->scenario_element) {
-                                $db_job->testrun->scenario_element->is_fitted(1);
-                                $db_job->testrun->scenario_element->update();
-                        }
-                        $db_job->update;
-                        return $db_job;
+                # Check for unfinished dependencies
+                next unless $job->dependencies_finished;
+
+                # Reserves resources, must run if $resources_available is 1
+                my ($resources_available,$acquireable_resources) =
+                  $job->claim_resources($available_resources);
+                next unless $resources_available;
+
+                my $db_job = model('TestrunDB')->resultset('TestrunScheduling')->find($job->{id});
+                $db_job->host_id ($host->id);
+
+                if ($db_job->testrun->scenario_element) {
+                        $db_job->testrun->scenario_element->is_fitted(1);
+                        $db_job->testrun->scenario_element->update();
                 }
+
+                $db_job->update;
+
+                return $db_job;
         }
         return;
 }
@@ -160,7 +171,7 @@ Tapper Team <tapper-ops@amazon.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2019 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2024 by Advanced Micro Devices, Inc.
 
 This is free software, licensed under:
 
