@@ -1,10 +1,13 @@
-package DbUser;
+package # hide from PAUSE indexer
+ DbUser;
 
 use strict;
 use warnings;
 
 use parent 'DBIx::Class';
 
+use lib "xt/";
+
 __PACKAGE__->load_components("Core");
 __PACKAGE__->table("dbuser");
 __PACKAGE__->add_columns
